@@ -2,9 +2,7 @@
 import asyncio
 import contextlib
 import functools
-import operator
 import time
-import uuid
 from typing import (
     Callable,
     List,
@@ -12,14 +10,12 @@ from typing import (
 )
 
 # Local libraries
+from tracers.analyzers import (
+    analyze_loop_snapshots,
+    analyze_stack,
+)
 from tracers.constants import (
-    CHAR_BROKEN_BAR,
-    CHAR_CHECK_MARK,
-    CHAR_INFO,
-    CHAR_SPACE,
-    CHAR_SUPERSCRIPT_ONE,
     LOOP_CHECK_INTERVAL,
-    LOOP_SKEW_TOLERANCE,
 )
 from tracers.containers import (
     Frame,
@@ -86,102 +82,17 @@ def record_event(
     function: Callable,
     function_name: str = '',
 ):
+    _function_name, _function_signature = get_function_id(function)
+
     STACK.get().append(Frame(
         event=event,
-        function=get_function_id(function, function_name),
+        function=function_name or _function_name,
         level=LEVEL.get(),
+        signature=_function_signature,
         timestamp=time.clock_gettime(clock_id),
     ))
 
 
-def analyze_stack(stack: List[Frame]):
-    stack_levels: List[int] = [frame.level for frame in stack]
-
-    total_time_seconds: float = \
-        stack[-1].timestamp - stack[0].timestamp
-
-    print()
-    print(
-        f'{CHAR_INFO} Finished transaction: {uuid.uuid4().hex}, '
-        f'{total_time_seconds:.2f} seconds')
-    print()
-    print('  #    Timestamp       %     Total    Nested Call Chain')
-    print()
-
-    counter: int = 0
-    for index, frame in enumerate(stack):
-        indentation: str = (
-            (CHAR_SPACE * 3 + CHAR_BROKEN_BAR) * (frame.level - 1)
-            + (CHAR_SPACE * 3 + CHAR_CHECK_MARK)
-        )
-
-        if frame.event == 'call':
-            counter += 1
-            frame_childs: List[Frame] = \
-                stack[index:stack_levels.index(frame.level, index + 1) + 1]
-
-            relative_timestamp: float = \
-                frame.timestamp - stack[0].timestamp
-
-            raw_time_seconds: float = \
-                frame_childs[-1].timestamp - frame_childs[0].timestamp
-
-            raw_time_ratio: float = 100.0 * divide(
-                numerator=raw_time_seconds,
-                denominator=total_time_seconds,
-                on_zero_denominator=1.0,
-            )
-
-            print(
-                f'{counter:>6} '
-                f'{relative_timestamp:>8.2f}s '
-                f'{raw_time_ratio:>6.1f}% '
-                f'{raw_time_seconds:>8.2f}s '
-                f'{indentation} '
-                f'{frame.function}'
-            )
-
-
-def analyze_loop_snapshots(
-    snapshots: List[LoopSnapshot],
-):
-    top_snapshots: List[LoopSnapshot] = sorted(
-        [
-            snapshot
-            for snapshot in snapshots
-            if snapshot.block_duration_ratio > 1.0 + LOOP_SKEW_TOLERANCE
-        ],
-        key=operator.attrgetter('real_tick_duration'),
-        reverse=True,
-    )
-
-    if top_snapshots:
-        print()
-        print(
-            f'  Some blocks (skews) occurred in the event loop'
-            f' {CHAR_SUPERSCRIPT_ONE}'
-        )
-        print()
-        print('  #    Timestamp     Delay')
-        print()
-        initial_timestamp: float = snapshots[0].timestamp
-        for counter, snapshot in enumerate(top_snapshots):
-            skew: float = \
-                snapshot.real_tick_duration - snapshot.wanted_tick_duration
-
-            print(
-                f'{counter:>6} '
-                f'{snapshot.timestamp - initial_timestamp:>8.2f}s '
-                f'{skew:>8.2f}s '
-            )
-        print()
-        print(
-            f'  {CHAR_SUPERSCRIPT_ONE}'
-            f' Consider reviewing them carefully'
-            f' to improve the overall system throughput'
-        )
-
-
 def _get_wrapper(  # noqa: MC001
     *,
     clock_id: int = time.CLOCK_MONOTONIC,
