@@ -7,9 +7,14 @@ from contextvars import (
 import inspect
 from typing import (
     Callable,
+    Tuple,
 )
 
 
+def delta(start_timestamp: float, end_timestamp: float):
+    return end_timestamp - start_timestamp
+
+
 def divide(
     *,
     numerator: float,
@@ -20,7 +25,7 @@ def divide(
         on_zero_denominator if denominator == 0.0 else numerator / denominator
 
 
-def get_function_id(function: Callable, function_name: str = '') -> str:
+def get_function_id(function: Callable) -> Tuple[str, str]:
     # Adding decorators to a function modify its metadata
     #   Fortunately functools' wrapped functions keep a reference to the parent
     while hasattr(function, '__wrapped__'):
@@ -31,14 +36,14 @@ def get_function_id(function: Callable, function_name: str = '') -> str:
         signature = str(inspect.signature(function))
 
     module: str = function.__module__
-    name: str = function_name or function.__name__
+    name: str = function.__name__
     prefix = 'async ' * asyncio.iscoroutinefunction(function)
     signature = signature if len(signature) < 48 else '(...)'
 
     if module not in {'__main__'}:
-        return f'{prefix}{module}.{name}{signature}'
+        return f'{prefix}{module}.{name}', signature
 
-    return f'{prefix}{name}{signature}'
+    return f'{prefix}{name}', signature
 
 
 @contextlib.contextmanager
@@ -48,3 +53,7 @@ def increase_counter(contextvar):
         yield
     finally:
         contextvar.reset(token)
+
+
+def log(*parts):
+    return print(*parts)
